pub struct JournalistSetupResponse {
pub sig: Signature<NewsroomOnJournalist>,
}Expand description
Response from the newsroom to the journalist for initial onboarding.
Step 3.1 in the spec.
Fields
sig: Signature<NewsroomOnJournalist>A signature over the journalist enrollment bundle by the newsroom signing key