NewsroomSetupRequest

Struct NewsroomSetupRequest 

pub struct NewsroomSetupRequest {
    pub newsroom_verifying_key: VerifyingKey,
}
Request from the newsroom to FPF for verification.

Step 2 in the spec.

Fields

newsroom_verifying_key: VerifyingKey

Implementations

Source

impl NewsroomSetupRequest

pub fn sign(self, fpf_keys: &FPFKeyPair) -> Result<NewsroomSetupResponse, Error>

Setup a newsroom. This corresponds to step 2 in the spec.

This runs on FPF hardware.

The generated newsroom verifying key is sent to FPF, which produces a signature over the newsroom verifying key using the FPF signing key.

Security

There is a manual verification step here: the caller should instruct the user to stop, verify the fingerprint out of band, and then proceed. The caller should also persist the fingerprint and signature in its local data store.